==> jc-1.4.0.tar.gz: java/lang/Process.h <==
// public abstract class java.lang.Process

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 328115bde310c622 java_lang_Process

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Process_H_
#define _JC_java_lang_Process_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Process$sub_refs	_jc_java_lang_Process$sub_refs;
typedef struct _jc_java_lang_Process$sub_nonrefs	_jc_java_lang_Process$sub_nonrefs;
typedef struct _jc_java_lang_Process$refs	_jc_java_lang_Process$refs;
typedef struct _jc_java_lang_Process$nonrefs	_jc_java_lang_Process$nonrefs;
typedef struct _jc_java_lang_Process$object	_jc_java_lang_Process$object;

typedef const struct _jc_java_lang_Process$vmethods	_jc_java_lang_Process$vmethods;
typedef const struct _jc_java_lang_Process$vtable	_jc_java_lang_Process$vtable;
typedef const struct _jc_java_lang_Process$vtype	_jc_java_lang_Process$vtype;

// Constructors
extern void _jc_java_lang_Process$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Process$object *);

// Virtual methods
extern void _jc_java_lang_Process$method$destroy$883b1ab213ac7851(_jc_env *, struct _jc_java_lang_Process$object *);
extern jint _jc_java_lang_Process$method$exitValue$814ebd1217eadfe3(_jc_env *, struct _jc_java_lang_Process$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_lang_Process$method$getErrorStream$2bb9a2bd3f868836(_jc_env *, struct _jc_java_lang_Process$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_lang_Process$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_lang_Process$object *);
extern struct _jc_java_io_OutputStream$object *_jc_java_lang_Process$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_java_lang_Process$object *);
extern jint _jc_java_lang_Process$method$waitFor$c1bcd714b9380d71(_jc_env *, struct _jc_java_lang_Process$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_Process$method_info$destroy$883b1ab213ac7851;
extern _jc_method _jc_java_lang_Process$method_info$exitValue$814ebd1217eadfe3;
extern _jc_method _jc_java_lang_Process$method_info$getErrorStream$2bb9a2bd3f868836;
extern _jc_method _jc_java_lang_Process$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_lang_Process$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_java_lang_Process$method_info$waitFor$c1bcd714b9380d71;

// Virtual methods structure
struct _jc_java_lang_Process$vmethods {
	void	(*destroy$883b1ab213ac7851)(_jc_env *, struct _jc_java_lang_Process$object *);
	jint	(*exitValue$814ebd1217eadfe3)(_jc_env *, struct _jc_java_lang_Process$object *);
	struct _jc_java_io_InputStream$object	*(*getErrorStream$2bb9a2bd3f868836)(_jc_env *, struct _jc_java_lang_Process$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_lang_Process$object *);
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_java_lang_Process$object *);
	jint	(*waitFor$c1bcd714b9380d71)(_jc_env *, struct _jc_java_lang_Process$object *);
};

// Vtable
struct _jc_java_lang_Process$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Process$vmethods	java_lang_Process;
};

// Vtype
struct _jc_java_lang_Process$vtype {
	_jc_type			type;
	_jc_java_lang_Process$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Process$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Process$refs {
    _jc_java_lang_Process$sub_refs	java_lang_Process;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Process$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Process$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Process$sub_nonrefs	java_lang_Process;
};

// Object instance structure
struct _jc_java_lang_Process$object {
	_jc_java_lang_Process$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Process$vtype	*vtype;
	_jc_java_lang_Process$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Process$vtype _jc_java_lang_Process$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Process, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Process$class_object;

#endif	/* _JC_java_lang_Process_H_ */

==> jc-1.4.6.tar.gz: java/lang/Process.h <==
// public abstract class java.lang.Process

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 328115bde310c622 java_lang_Process

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Process_H_
#define _JC_java_lang_Process_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Process$sub_refs	_jc_java_lang_Process$sub_refs;
typedef struct _jc_java_lang_Process$sub_nonrefs	_jc_java_lang_Process$sub_nonrefs;
typedef struct _jc_java_lang_Process$refs	_jc_java_lang_Process$refs;
typedef struct _jc_java_lang_Process$nonrefs	_jc_java_lang_Process$nonrefs;
typedef struct _jc_java_lang_Process$object	_jc_java_lang_Process$object;

typedef const struct _jc_java_lang_Process$vmethods	_jc_java_lang_Process$vmethods;
typedef const struct _jc_java_lang_Process$vtable	_jc_java_lang_Process$vtable;
typedef const struct _jc_java_lang_Process$vtype	_jc_java_lang_Process$vtype;

// Constructors
extern void _jc_java_lang_Process$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_lang_Process$method$destroy$883b1ab213ac7851(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Process$method$exitValue$814ebd1217eadfe3(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_lang_Process$method$getErrorStream$2bb9a2bd3f868836(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_lang_Process$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_java_lang_Process$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Process$method$waitFor$c1bcd714b9380d71(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_Process$method_info$destroy$883b1ab213ac7851;
extern _jc_method _jc_java_lang_Process$method_info$exitValue$814ebd1217eadfe3;
extern _jc_method _jc_java_lang_Process$method_info$getErrorStream$2bb9a2bd3f868836;
extern _jc_method _jc_java_lang_Process$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_lang_Process$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_java_lang_Process$method_info$waitFor$c1bcd714b9380d71;

// Virtual methods structure
struct _jc_java_lang_Process$vmethods {
	void	(*destroy$883b1ab213ac7851)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
	jint	(*exitValue$814ebd1217eadfe3)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getErrorStream$2bb9a2bd3f868836)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
	jint	(*waitFor$c1bcd714b9380d71)(_jc_env *, struct _jc_java_lang_Process$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_Process$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Process$vmethods	java_lang_Process;
};

// Vtype
struct _jc_java_lang_Process$vtype {
	_jc_type			type;
	_jc_java_lang_Process$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Process$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Process$refs {
    _jc_java_lang_Process$sub_refs	java_lang_Process;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Process$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Process$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Process$sub_nonrefs	java_lang_Process;
};

// Object instance structure
struct _jc_java_lang_Process$object {
	_jc_java_lang_Process$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Process$vtype	*vtype;
	_jc_java_lang_Process$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Process$vtype _jc_java_lang_Process$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Process, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Process$class_object;

#endif	/* _JC_java_lang_Process_H_ */
